@@ -16,7 +16,7 @@ class MDDF():
             eff = self.__DDFmodel(i,self.data)
             TE.append(eff)
         self.data['DDF效率'] = TE
-        return self.data[self.input+self.output+self.unoutput+['DDF效率']]
+        return self.data[[self.data.columns.values[0]]+self.input+self.output+self.unoutput+['DDF效率']]
     
     def __DDFmodel(self, i,data):
         model = Model('DDF')
@@ -34,9 +34,9 @@ class MDDF():
             elif self.dd == '(-x,y,-b)强可处置性>=':
                     model.addConstrs(quicksum(lambdas[j] * data.loc[j,u] for j in self.K) 
                          >= (1-beta) * data.loc[i,u]  for u in self.unoutput)
-            elif self.dd == '(-x,y,-b)强可处置性<=':
+            elif self.dd == '(-x,y,b)强可处置性<=':
                     model.addConstrs(quicksum(lambdas[j] * data.loc[j,u] for j in self.K) 
-                         <= (1-beta) * data.loc[i,u]  for u in self.unoutput)
+                         <= (1+beta) * data.loc[i,u]  for u in self.unoutput)
         if self.key == '规模报酬可变VRS':
             model.addConstr(quicksum(lambdas[j] for j in self.K) == 1)
         model.setObjective(beta, GRB.MAXIMIZE)
